@@ -92,6 +92,17 @@ class TestSQLite(Validator):
             read={"snowflake": "LEAST(x, y, z)"},
             write={"snowflake": "LEAST(x, y, z)"},
         )
+        self.validate_all(
+            "UNICODE(x)",
+            write={
+                "": "UNICODE(x)",
+                "mysql": "ORD(CONVERT(x USING utf32))",
+                "oracle": "ASCII(UNISTR(x))",
+                "postgres": "ASCII(x)",
+                "redshift": "ASCII(x)",
+                "spark": "ASCII(x)",
+            },
+        )
         self.validate_identity(
             "SELECT * FROM station WHERE city IS NOT ''",
             "SELECT * FROM station WHERE NOT city IS ''",
@@ -222,3 +233,7 @@ class TestSQLite(Validator):
                 "mysql": "CREATE TABLE `x` (`Name` VARCHAR(200) NOT NULL)",
             },
         )
+
+        self.validate_identity(
+            "CREATE TABLE store (store_id INTEGER PRIMARY KEY AUTOINCREMENT, mgr_id INTEGER NOT NULL UNIQUE REFERENCES staff ON UPDATE CASCADE)"
+        )
